@@ -3,10 +3,10 @@
 auROC <- function(truth, stat=NULL)
 #	Area under Receiver Operating Curve for empirical data
 #	Gordon Smyth
-#	21 Dec 2003. Last modified 28 April 2015.
+#	Created 21 Dec 2003. Last modified 20 Jun 2020.
 {
 #	Don't allow any NA
-	if(any(is.na(truth))) return(NA)
+	if(anyNA(truth)) return(NA)
 
 #	Make logical and integer vectors
 	ntests <- length(truth)
@@ -27,7 +27,7 @@ auROC <- function(truth, stat=NULL)
 #	Check stat
 	stat <- as.vector(stat)
 	if(length(stat) != ntests) stop("lengths differ")
-	if(any(is.na(stat))) return(NA)
+	if(anyNA(stat)) return(NA)
 
 #	From here, stat is not NA
 
@@ -48,7 +48,7 @@ auROC <- function(truth, stat=NULL)
 		sensitivity.last <- sensitivity[tied.last]
 		sensitivity.previous <- c(0,sensitivity.last[-length(sensitivity.last)])
 		sensitivity.average <- (sensitivity.last+sensitivity.previous)/2
-		sensitivity <- rep(sensitivity.average, tied.last-tied.first+1)
+		sensitivity <- rep.int(sensitivity.average, tied.last-tied.first+1)
 	}
 
 	mean(sensitivity[!truthl])
