@@ -33,7 +33,7 @@ eBayes <- function(fit,proportion=0.01,stdev.coef.lim=c(0.1,4),trend=FALSE,robus
 .ebayes <- function(fit,proportion=0.01,stdev.coef.lim=c(0.1,4),trend=FALSE,robust=FALSE,winsor.tail.p=c(0.05,0.1))
 #	Empirical Bayes statistics to select differentially expressed genes
 #	Gordon Smyth
-#	8 Sept 2002.  Last revised 1 May 2013.
+#	Created 8 Sept 2002.  Last revised 12 Apr 2020.
 #	Made a non-exported function 18 Feb 2018.
 {
 	coefficients <- fit$coefficients
@@ -41,8 +41,8 @@ eBayes <- function(fit,proportion=0.01,stdev.coef.lim=c(0.1,4),trend=FALSE,robus
 	sigma <- fit$sigma
 	df.residual <- fit$df.residual
 	if(is.null(coefficients) || is.null(stdev.unscaled) || is.null(sigma) || is.null(df.residual)) stop("No data, or argument is not a valid lmFit object")
-	if(all(df.residual==0)) stop("No residual degrees of freedom in linear model fits")
-	if(all(!is.finite(sigma))) stop("No finite residual standard deviations")
+	if(max(df.residual)==0) stop("No residual degrees of freedom in linear model fits")
+	if(!any(is.finite(sigma))) stop("No finite residual standard deviations")
 	if(trend) {
 		covariate <- fit$Amean
 		if(is.null(covariate)) stop("Need Amean component in fit to estimate trend")
@@ -65,7 +65,7 @@ eBayes <- function(fit,proportion=0.01,stdev.coef.lim=c(0.1,4),trend=FALSE,robus
 #	B-statistic
 	var.prior.lim <- stdev.coef.lim^2/median(out$s2.prior)
 	out$var.prior <- tmixture.matrix(out$t,stdev.unscaled,df.total,proportion,var.prior.lim)
-	if(any(is.na(out$var.prior))) {
+	if(anyNA(out$var.prior)) {
 		out$var.prior[ is.na(out$var.prior) ] <- 1/out$s2.prior
 		warning("Estimation of var.prior failed - set to default value")
 	}
@@ -107,7 +107,7 @@ tmixture.vector <- function(tstat,stdev.unscaled,df,proportion,v0.lim=NULL)
 #	tstat is assumed to follow sqrt(1+v0/v1)*t(df) with probability proportion and t(df) otherwise
 #	v1 is stdev.unscaled^2 and v0 is to be estimated
 #	Gordon Smyth
-#	18 Nov 2002.  Last modified 15 April 2016.
+#	18 Nov 2002.  Last modified 9 Jun 2020.
 {
 #	Remove missing values
 	if(anyNA(tstat)) {
@@ -145,7 +145,7 @@ tmixture.vector <- function(tstat,stdev.unscaled,df,proportion,v0.lim=NULL)
 	r <- 1:ntarget
 	p0 <- 2*pt(tstat,df=MaxDF,lower.tail=FALSE)
 	ptarget <- ( (r-0.5)/ngenes - (1-p)*p0 ) / p
-	v0 <- rep.int(0,ntarget)
+	v0 <- rep_len(0,length.out=ntarget)
 	pos <- ptarget > p0
 	if(any(pos)) {
 		qtarget <- qt(ptarget[pos]/2,df=MaxDF,lower.tail=FALSE)
